@@ -65,7 +65,7 @@ async def handle_scores(source, signal, **kwargs):
 		return dict(
 			player=player,
 			best_lap_checkpoints=data['bestlapcheckpoints'],
-			match_points=data['mappoints'], rank=data['rank'], best_lap_time=data['bestlaptime'],
+			match_points=data['matchpoints'], rank=data['rank'], best_lap_time=data['bestlaptime'],
 			map_points=data['mappoints'], best_race_time=data['bestracetime'],
 			round_points=data['roundpoints'], best_race_checkpoints=data['bestracecheckpoints'],
 
@@ -105,6 +105,7 @@ async def handle_scores(source, signal, **kwargs):
 		section=source['section']
 	)
 
+
 async def handle_stunt(source, signal, **kwargs):
 	player = await Controller.instance.player_manager.get_player(login=source['login'])
 	return dict(
@@ -465,3 +466,50 @@ warmup_status = Callback(
 :type available: bool
 :type active: bool
 """
+
+
+tmnext_properties = Callback(
+	call='Script.Common.UIModules.Properties',
+	namespace='trackmania',
+	code='common_uimodules_properties',
+	target=handle_generic
+)
+"""
+:Signal:
+	Common.UIModules.Properties for TM2020
+:Code:
+	``trackmania:common_uimodules_properties``
+:Description:
+	Returns UIModules Properties like for instance: Race_Chrono see: ``[{'id': 'Race_Chrono', 'position': [0, -80], 'scale': 1, 'visible': True},``
+:Original Callback:
+	`Script` Common.UIModules.Properties
+
+:param responseid: Internally used. Ignore
+:param uimodules: Collection of all UIModules in TM2020.
+:type id Name of the UIModule
+:type position Position to place/get Position [0,-80] as example
+:type scale Scale measurement
+:type visible Boolean True or False
+"""
+
+
+tmnext_ko_elimination = Callback(
+	call='Script.Trackmania.Knockout.Elimination',
+	namespace='trackmania',
+	code='tmnext_ko_elimination',
+	target=handle_generic
+)
+"""
+:Signal:
+	Knockout Elimination Callback.
+:Code:
+	``trackmania:knockout_Elimination``
+:Description:
+	Returns a webserviceId on Player Knockout.
+:Original Callback:
+	`Script` Trackmania.Knockout.Elimination
+
+:param responseid: Internally used. Ignore
+:param account-id: example: ab6fa572-48d7-4b16-a2d7-5c760a05f97b.
+
+"""
